@@ -5,12 +5,16 @@ fisherTestTab <- function(tab) {
 
 	nbGroupes <- nrow(tab)/2 # le nombre de groupes
 	nbVars <- ncol(tab) # le nombre de variables
+	nomsGroupes <- substr(rownames(tab)[1:nbGroupes], 3, nchar(rownames(tab)[1:nbGroupes])) # le nom des groupes
 	MatRes <- matrix(NA, ncol=nbVars, nrow=nbGroupes*(nbGroupes-1)/2) # matrice de p-valeurs qui dira si chaque trait est informatif ou non pour chaque paire de groupes
+	colnames(MatRes) <- colnames(tab)
+	rownames(MatRes) <- 1:10 # initialisation à une valeur idiote pour éviter une erreur ci-dessous (il *faut* que le nom des lignes soit initialisé)
 	
 	for (j in 1:nbVars) { # pour chaque trait...
 		compteurLignes <- 1
 		for (k in 1:(nbGroupes-1)) { # ... et chaque paire...
 			for (l in (k+1):nbGroupes) { # ... de groupes...
+				rownames(MatRes)[compteurLignes] <- paste(nomsGroupes[k], nomsGroupes[l], sep=" - ")
 				presGroupeA <- round(tab[k,j] * tab[(k+nbGroupes),j])
 				presGroupeB <- round(tab[l,j] * tab[(l+nbGroupes),j])
 				absGroupeA <- round(tab[k,j] * (1-tab[(k+nbGroupes),j]))
@@ -22,5 +26,5 @@ fisherTestTab <- function(tab) {
 		}
 	}
 	isInformative <- apply(MatRes, MARGIN=2, FUN= function(x) if (any(x<=0.05)) return(TRUE) else return(FALSE))
-	return(tab[ , isInformative])
+	return(list(informative=tab[ , isInformative], pval=MatRes))
 }
